{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "scass-scanner.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "scass-scanner.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
### NOT CONFIGURABLE
### Environs listed below are NOT CONFIGURABLE
# NOTE: if you change .Values.environs for these, they will be duplicated and may cause unwanted behavior
### END NOT CONFIGURABLE
*/}}
{{- define "scass-scanner.defaultNonConfigurableEnvirons" -}}
MANAGER_HOST: {{ .Values.bds.manager.host }}
MANAGER_PORT: "{{ .Values.bds.manager.port }}"
PRODUCT_NAME: SCA_SCAN_SERVICE
VERSION: {{ .Values.image.tag }}
RABBITMQ_HOST: {{ .Values.bds.rabbitmq.host }}
RABBITMQ_VHOST: "scass"
{{- end -}}

{{- define "scass-scanner.environs" }}
{{- range $key, $value := .Values.environs }}
{{ $key }}: {{ $value | quote }}
{{- end }}
{{- end }}

{{- define "scass-scanner.global.environs" }}
{{- range $key, $value := .Values.global.environs }}
{{ $key }}: {{ $value | quote }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "scass-scanner.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "scass-scanner.labels" -}}
helm.sh/chart: {{ include "scass-scanner.chart" . }}
{{ include "scass-scanner.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "scass-scanner.selectorLabels" -}}
app.kubernetes.io/name: {{ include "scass-scanner.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the service account to use
*/}}
{{- define "scass-scanner.serviceAccountName" -}}
{{- if .Values.serviceAccount.create }}
{{- default (include "scass-scanner.fullname" .) .Values.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.serviceAccount.name }}
{{- end }}
{{- end }}

{{/*
Image pull secrets to pull the image
*/}}
{{- define "scass-scanner.imagePullSecrets" }}
{{- if .Values.imagePullSecrets -}}
imagePullSecrets:
{{- range .Values.imagePullSecrets }}
  - name: {{ . }}
{{- end }}
{{- end }}
{{- end }}

{{- define "scass-scanner.rabbitmq.fqdn" }}
{{- $rabbitusername := "scassuser" }}
{{- $rabbitpassword := "blackduck" }}
{{- $rabbitcredentials := (lookup "v1" "Secret" .Release.Namespace "scass-rabbitmq-credentials") }}
{{- if $rabbitcredentials.data }}
{{- $rabbitusername := index $rabbitcredentials.data "username" }}
{{- $rabbitpassword := index $rabbitcredentials.data "password" }}
{{- end }}
{{- printf "http://%s:%s@%s.%s.svc.cluster.local:15672" $rabbitusername $rabbitpassword .Values.bds.rabbitmq.host .Release.Namespace | b64enc }}
{{- end }}